@@ -269,18 +269,13 @@ class HealthLogUi:
 			print(e)
 
 	def export_log(self):
-		try:
-			with BooleanAnswers.IllegalCharsManifest.open("w") as output:
-				output.write("Below is a list of Characters replaced with a non-illegal equivalents.\n")
-				output.write("Replacement in Text = Character\n")
-		except Exception as e:
-			print(e)
 		useDateRange=Prompt.__init2__(None,func=FormBuilderMkText,ptext="use a date range?",helpText="yes or no",data="boolean")
 		if useDateRange is None:
 			return
 		elif useDateRange in ['d',]:
 			useDateRange=True
-		output=Path("HealthLogAll.xlsx")
+		fil=Path("HealthLogAll.xlsx")
+		output=pd.ExcelWriter(fil)
 		with Session(ENGINE) as session:
 			query=session.query(HealthLog)
 			query=orderQuery(query,HealthLog.DTOE)
@@ -305,25 +300,37 @@ class HealthLogUi:
 			
 			#str.replace(lambda x:x,lambda x:strip_colors(x))
 			#df=df.apply(remove_illegals)
+			def remove_illegals(x):
+				return x
 			for i in df:
 				df[i]=df[i].apply(lambda x:remove_illegals(strip_colors(x)) if isinstance(x,str) else x)
 				#df[i]=df[i].apply(remove_illegals)
-			df.to_excel(output,index=False)
+			sheetName="HealthLog"
+			df.to_excel(output,sheet_name=sheetName,index=False)
+
+			try:
+				for column in df:
+					column_length = 5+len(column)+5
+					col_idx = df.columns.get_loc(column)
+					output.sheets[sheetName].set_column(col_idx, col_idx, column_length)
+
+					col_idx = df.columns.get_loc('DTOE')
+					dtoe_length = max(df['DTOE'].astype(str).map(len).max(), len('DTOE'))
+					output.sheets[sheetName].set_column(col_idx, col_idx, dtoe_length)
+
+				
+				output.close()
+			except Exception as e:
+				print(e)
+
+
 			with zipfile.ZipFile(BooleanAnswers.HealthLogZip,"w") as oz:
 				oz.write(output)
-				oz.write(BooleanAnswers.IllegalCharsManifest)
-			print(output.absolute())
-			print(BooleanAnswers.IllegalCharsManifest.absolute())
+			print(fil.absolute())
 			print(f"{Fore.orange_red_1}The Below file only contains the above files!{Style.reset}")
 			print(BooleanAnswers.HealthLogZip.absolute())
 
 	def export_log_field(self,fields=[],not_none=[]):
-		try:
-			with BooleanAnswers.IllegalCharsManifest.open("w") as output:
-				output.write("Below is a list of Characters replaced with a non-illegal equivalents.\n")
-				output.write("Replacement in Text = Character\n")
-		except Exception as e:
-			print(e)
 		useDateRange=Prompt.__init2__(None,func=FormBuilderMkText,ptext="use a date range?",helpText="yes or no",data="boolean")
 		if useDateRange is None:
 			return
@@ -334,7 +341,8 @@ class HealthLogUi:
 			fields.append('DTOE')
 		if 'Comments' not in fields:
 			fields.append('Comments')
-		output=Path(f"HealthLog-fields.xlsx")
+		fil=Path(f"HealthLog-fields.xlsx")
+		output=pd.ExcelWriter(fil)
 		not_none=[i for i in HealthLog.__table__.columns if str(i.name) in not_none]
 		with Session(ENGINE) as session:
 			query=session.query(HealthLog).filter(or_(*[i!=None for i in not_none]))
@@ -359,14 +367,33 @@ class HealthLogUi:
 			df=pd.read_sql(query.statement,session.bind)
 
 			df=df[fields]
+			def remove_illegals(x):
+				return x
 			for i in df:
 				df[i]=df[i].apply(lambda x:remove_illegals(strip_colors(x)) if isinstance(x,str) else x)
-			df.to_excel(output,index=False)
+			
+			sheetName="HealthLog"
+			df.to_excel(output,sheet_name=sheetName,index=False)
+
+			try:
+				for column in df:
+					column_length = 5+len(column)+5
+					col_idx = df.columns.get_loc(column)
+					output.sheets[sheetName].set_column(col_idx, col_idx, column_length)
+
+					col_idx = df.columns.get_loc('DTOE')
+					dtoe_length = max(df['DTOE'].astype(str).map(len).max(), len('DTOE'))
+					output.sheets[sheetName].set_column(col_idx, col_idx, dtoe_length)
+
+					
+				
+				output.close()
+
+			except Exception as e:
+				print(e)
 			with zipfile.ZipFile(BooleanAnswers.HealthLogZip,"w") as oz:
 				oz.write(output)
-				oz.write(BooleanAnswers.IllegalCharsManifest)
-			print(output.absolute())
-			print(BooleanAnswers.IllegalCharsManifest.absolute())
+			print(fil.absolute())
 			print(f"{Fore.orange_red_1}The Below file only contains the above files!{Style.reset}")
 			print(BooleanAnswers.HealthLogZip.absolute())
 
@@ -609,11 +636,11 @@ class HealthLogUi:
 								for x in fields:
 									includes=[
 											"CarboHydrateIntake",
-										    "ProtienIntake",
-										    "FiberIntake",
-										    "TotalFat",
-										    "SodiumIntake",
-										    "CholesterolIntake",
+											"ProtienIntake",
+											"FiberIntake",
+											"TotalFat",
+											"SodiumIntake",
+											"CholesterolIntake",
 											]
 									if x.name not in includes:
 										continue
